Struct Form
pub struct Form<T>(pub T);Expand description
URL encoded extractor and response.
As extractor
If used as an extractor, Form will deserialize form data from the request,
specifically:
- If the request has a method of
GETorHEAD, the form data will be read from the query string (same as withQuery) - If the request has a different method, the form will be read from the body
of the request. It must have a
content-typeofapplication/x-www-form-urlencodedfor this to work. If you want to parsemultipart/form-datarequest bodies, useMultipartinstead.
This matches how HTML forms are sent by browsers by default.
In both cases, the inner type T must implement [serde::Deserialize].
โ ๏ธ Since parsing form data might require consuming the request body, the Form extractor must be
last if there are multiple extractors in a handler. See โthe order of
extractorsโ
use axum::Form;
use serde::Deserialize;
#[derive(Deserialize)]
struct SignUp {
username: String,
password: String,
}
async fn accept_form(Form(sign_up): Form<SignUp>) {
// ...
}As response
Form can also be used to encode any type that implements
[serde::Serialize] as application/x-www-form-urlencoded
use axum::Form;
use serde::Serialize;
#[derive(Serialize)]
struct Payload {
value: String,
}
async fn handler() -> Form<Payload> {
Form(Payload { value: "foo".to_owned() })
}Tuple Fields
0: TTrait Implementations
impl<T, S> FromRequest<S> for Form<T>
impl<T, S> FromRequest<S> for Form<T>
type Rejection = FormRejection
type Rejection = FormRejection
If the extractor fails itโll use this โrejectionโ type. A rejection is
a kind of error that can be converted into a response.
async fn from_request(
req: Request<Body>,
_state: &S,
) -> Result<Form<T>, <Form<T> as FromRequest<S>>::Rejection>
async fn from_request( req: Request<Body>, _state: &S, ) -> Result<Form<T>, <Form<T> as FromRequest<S>>::Rejection>
Perform the extraction.
impl<T> IntoResponse for Form<T>where
T: Serialize,
impl<T> IntoResponse for Form<T>where
T: Serialize,
fn into_response(self) -> Response<Body>
fn into_response(self) -> Response<Body>
Create a response.
impl<T> Copy for Form<T>where
T: Copy,